==> nsc-2.0.2-112-GA.update.tgz: var/webconfig/SAFe/application/views/safe_wait.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
//echo safe_webdialog($wait_message, '/templates/base/images/icons/16x16/icon-loading.gif', 'safe_wait');
if(!isset($wait_message)){
    $wait_message = '';
}else{
    $wait_message = str_replace("'",'',$wait_message);
}
if(!isset($timeout_sec)){
    $timeout_sec = 60;
}else{
    $timeout_sec = str_replace("'",'',$timeout_sec);
}
if(!isset($timeout_msg)){
    $timeout_msg = 'Ooops ! Server seems down...';
}else{
    $timeout_msg = str_replace("'",'',$timeout_msg);
}
if(!isset($timeout_label)){
    $timeout_label = 'Back';
}else{
    $timeout_label = str_replace("'",'',$timeout_label);
}
if(!isset($timeout_url)){
    $timeout_url = 'http'.(empty($_SERVER['HTTPS'])?'':'s').'://'.$_SERVER['HTTP_HOST'];
}else{
    $timeout_url = str_replace("'",'',$timeout_url);
}
$set_timeout = ",'$timeout_sec','$timeout_msg','$timeout_label','$timeout_url'";
?>
<script type="text/javascript">
var timeout_dialog = null;
var processing_ui = safe_wait('<?php echo $wait_message; ?>','spinning_wheel'<?php echo $set_timeout;?>);
$('document').ready(function() {
    //	$('.safe_wait').hide();
	processing_ui.dialog("close");
	if(timeout_dialog != null){
		timeout_dialog.dialog("close");
	}
});
</script>

==> nsc-2.1.13-61-GA.update.tgz: var/webconfig/SAFe/application/views/safe_wait.php <==
<?php
/** vim: set tabstop=4 softtabstop=4 shiftwidth=4 textwidth=80 smarttab expandtab: **/
/** coding: utf-8: **/
/*
 * Copyright (C) 2012  Sangoma Technologies Corp.
 * All Rights Reserved.
 *
 * Author(s)
 * your name <your_name@sangoma.com>
 *
 * This code is Sangoma Technologies Confidential Property.
 * Use of and access to this code is covered by a previously executed
 * non-disclosure agreement between Sangoma Technologies and the Recipient.
 * This code is being supplied for evaluation purposes only and is not to be
 * used for any other purpose.
*/
//echo safe_webdialog($wait_message, '/templates/base/images/icons/16x16/icon-loading.gif', 'safe_wait');
if(!isset($wait_message)){
    $wait_message = '';
}else{
    $wait_message = str_replace("'",'',$wait_message);
}
if(!isset($timeout_sec)){
    $timeout_sec = 60;
}else{
    $timeout_sec = str_replace("'",'',$timeout_sec);
}
if(!isset($timeout_msg)){
    $timeout_msg = 'Ooops ! Server seems down...';
}else{
    $timeout_msg = str_replace("'",'',$timeout_msg);
}
if(!isset($timeout_label)){
    $timeout_label = 'Back';
}else{
    $timeout_label = str_replace("'",'',$timeout_label);
}
if(!isset($timeout_url)){
    $timeout_url = 'http'.(empty($_SERVER['HTTPS'])?'':'s').'://'.$_SERVER['HTTP_HOST'];
}else{
    $timeout_url = str_replace("'",'',$timeout_url);
}
//get processing log from log url, and set a timeout if log no changes
if(!isset($log_url)){
    $log_url = 'http'.(empty($_SERVER['HTTPS'])?'':'s').'://'.$_SERVER['HTTP_HOST'];
}else{
    $log_url = str_replace("'",'',$log_url);
}
if(!isset($log_timeout)){
    $log_timeout = '300';
}else{
    $log_timeout = str_replace("'",'',$log_timeout);
}
$set_timeout = ",'$timeout_sec','$timeout_msg','$timeout_label','$timeout_url','$log_url','$log_timeout'";
if(!isset($ui_type)){
    $ui_type = 'spinning_wheel';
}
?>
<script type="text/javascript">
var timeout_dialog = null;
var page_is_ready = false;
$(document).keydown(function(e) {
    if(!page_is_ready){
        if (e.keyCode == 27) return false;
    }
});
var processing_ui = safe_wait('<?php echo $wait_message; ?>','<?php echo $ui_type;?>'<?php echo $set_timeout;?>);
$('document').ready(function() {
    page_is_ready = true;
    //	$('.safe_wait').hide();
	processing_ui.dialog("close");
	if(timeout_dialog != null){
		timeout_dialog.dialog("close");
	}
	clearTimeout(processing_log_timeout_obj);
});
</script>
